package com.ruoyi.bst.refund.mapper;

import java.math.BigDecimal;
import java.util.List;

import org.apache.ibatis.annotations.Param;

import com.ruoyi.bst.refund.domain.Refund;
import com.ruoyi.bst.refund.domain.RefundQuery;
import com.ruoyi.bst.refund.domain.RefundVO;
import com.ruoyi.bst.refund.domain.vo.RefundDailyStatVO;

/**
 * 退款Mapper接口
 *
 * @author ruoyi
 * @date 2025-03-28
 */
public interface RefundMapper
{
    /**
     * 查询退款
     *
     * @param id 退款主键
     * @return 退款
     */
    RefundVO selectRefundById(Long id);

    /**
     * 查询退款列表
     *
     * @param query 退款
     * @return 退款集合
     */
    List<RefundVO> selectRefundList(@Param("query")RefundQuery query);

    /**
     * 新增退款
     *
     * @param refund 退款
     * @return 结果
     */
    int insertRefund(Refund refund);


    /**
     * 修改退款
     *
     * @param refund 退款
     * @return 结果
     */
    public int updateRefund(@Param("data") Refund refund);

    /**
     * 删除退款
     *
     * @param id 退款主键
     * @return 结果
     */
    int deleteRefundById(Long id);

    /**
     * 批量删除退款
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRefundByIds(Long[] ids);

    /**
     * 根据条件更新退款
     * @param data 退款
     * @param query 条件
     * @return 结果
     */
    int updateByQuery(@Param("data") Refund data, @Param("query") RefundQuery query);

    /**
     * 查询退款金额
     * @param query
     * @return
     */
    BigDecimal selectSumofAmount(@Param("query") RefundQuery query);

    /**
     * 查询每日统计
     * @param query
     * @param keys
     * @return
     */
    List<RefundDailyStatVO> selectDailyRefundStat(@Param("query") RefundQuery query, @Param("keys") List<String> keys);
}
